@@ -1,4 +1,5 @@
 import enum
+import re
 import secrets
 
 from jwcrypto import jwk
@@ -12,6 +13,10 @@ from fief.models.base import WorkspaceBase
 from fief.models.generics import GUID, CreatedUpdatedAt, UUIDModel
 from fief.models.tenant import Tenant
 
+LOCALHOST_HOST_PATTERN = re.compile(
+    r"([^\.]+\.)?localhost(\d+)?|127\.0\.0\.1", flags=re.IGNORECASE
+)
+
 
 def get_default_redirect_uris() -> list[str]:
     return ["http://localhost:8000/docs/oauth2-redirect"]
@@ -21,6 +26,17 @@ class ClientType(str, enum.Enum):
     PUBLIC = "public"
     CONFIDENTIAL = "confidential"
 
+    def get_display_name(self) -> str:
+        display_names = {
+            ClientType.PUBLIC: "Public",
+            ClientType.CONFIDENTIAL: "Confidential",
+        }
+        return display_names[self]
+
+    @classmethod
+    def get_choices(cls) -> list[tuple[str, str]]:
+        return [(member.value, member.get_display_name()) for member in cls]
+
 
 class Client(UUIDModel, CreatedUpdatedAt, WorkspaceBase):
     __tablename__ = "clients"
