@@ -1,5 +1,4 @@
 from datetime import datetime, timezone
-from typing import Optional
 
 from sqlalchemy import select
 
@@ -14,13 +13,13 @@ class AuthorizationCodeRepository(
 ):
     model = AuthorizationCode
 
-    async def get_valid_by_code(self, code: str) -> Optional[AuthorizationCode]:
+    async def get_valid_by_code(self, code: str) -> AuthorizationCode | None:
         statement = select(AuthorizationCode).where(
             AuthorizationCode.code == code,
             AuthorizationCode.expires_at > datetime.now(timezone.utc),
         )
         return await self.get_one_or_none(statement)
 
-    async def get_by_code(self, code: str) -> Optional[AuthorizationCode]:
+    async def get_by_code(self, code: str) -> AuthorizationCode | None:
         statement = select(AuthorizationCode).where(AuthorizationCode.code == code)
         return await self.get_one_or_none(statement)
