@@ -1,10 +1,11 @@
 import random
 import string
+import uuid
 
 from slugify import slugify
 from sqlalchemy import select
 
-from fief.models import Workspace
+from fief.models import Workspace, WorkspaceUser
 from fief.repositories.base import BaseRepository, UUIDRepositoryMixin
 from fief.settings import settings
 
@@ -12,6 +13,14 @@ from fief.settings import settings
 class WorkspaceRepository(BaseRepository[Workspace], UUIDRepositoryMixin[Workspace]):
     model = Workspace
 
+    async def get_by_admin_user(self, user_id: uuid.UUID) -> list[Workspace]:
+        statement = (
+            select(Workspace)
+            .join(Workspace.workspace_users)
+            .where(WorkspaceUser.user_id == user_id)
+        )
+        return await self.list(statement)
+
     async def get_by_domain(self, domain: str) -> Workspace | None:
         statement = select(Workspace).where(Workspace.domain == domain)
         return await self.get_one_or_none(statement)
